<?php
/*
 * @component Tablebooking
 * @website : ionutlupu.me
 * @copyright  Ionut Lupu. All rights reserved.
 * @license : http://www.gnu.org/copyleft/gpl.html GNU/GPL , see license.txt
 */


// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.controlleradmin');

class TableBookingControllerBookings extends JControllerAdmin {

	public function getModel($name = 'Booking', $prefix = 'TableBookingModel', $config = array('ignore_request' => true)) {
		$model = parent::getModel($name, $prefix, $config);
		return $model;
	}


	/**
	 * return all free hours available for a certain table/date combination
	 * triggered in the dashboard using ajax
	 */
	public function getFreeHours()
	{
		$date = JRequest::getVar('date',null,'','string');
		$id = JRequest::getVar('id',0,'','int');
		$response = new stdclass;
		$response->hours = array();
		$response->error = 0;

		if(preg_match('/^[0-9]{4}(-[0-9]{2}){2}$/',$date))
		{
			$bookings = TbBookingsList::getInstance($date)->clear()->forTable($id)->filter;
			$date = TbSchedule::getDate($date);
			$restaurant = TbUser::getInstance()->work->restaurant;

			$schedule = $restaurant->getSchedule($date);
			// if a schedule for that certain date doesn't exist default to the schedule for the week day
			if (!$schedule->isSet)
			{
				$schedule = $restaurant->getSchedule($date->__get('dayofweek'));
			}

			if (!$schedule->working)
			{
				$response->error = JText::_('COM_TABLEBOOKING_NON_WORKING');
			}
			else
			{
				$hours = $schedule->getHours(true);

				foreach ($bookings as $booking)
				{
					foreach ($hours as $key=>$value)
					{
						if ($booking->bookstart <= $key && $key<$booking->bookend)
						{
							unset($hours[$key]);
						}
					}
				}

				$response->hours = $hours;
			}
		}
		else
		{
			$response->error = JText::_('COM_TABLEBOOKING_INVALID_DATE');
		}


		echo json_encode($response);
		exit(0);
	}


	/**
	 * get a response with an associative array containing table:status at a certain date and hour
	 *
	 */
	public function forDayHour()
	{
		$day = JRequest::getVar('day',null,'','string');
		$hour = JRequest::getVar('hour',0,'','int');
		$response = array();
		if(preg_match('/^[0-9]{4}(-[0-9]{2}){2}$/',$day) && preg_match('/^[0-9]{4,}$/',$hour))
		{
			$bookings = TbBookingsList::getInstance($day)->clear()->forHour($hour)->filter;
			$tables = TbUser::getInstance()->work->restaurant->getTables();

			if ($bookings)
			{
				foreach ($bookings as $booking)
				{
					$booked_tables = json_decode($booking->table);
					foreach ($booked_tables as $table)
					{
						$response[$table] = $booking->status;
					}
				}
			}

			foreach ($tables as $table)
			{
				if (!isset($response[$table->id]))
				{
					$response[$table->id] = '-1';
				}
			}

		}
		echo json_encode($response);
		exit(0);
	}


	public function confirm() {
    	$input = JFactory::getApplication()->input;
		$pks = $input->get('cid', array(), 'array');

		if (!empty($pks)) {
			$model = $this->getModel('Booking');
			$table = $model->getTable();
			foreach ($pks as $pk) {
    			$table->load($pk);
    			$table->status = 1;
    			$table->store();
			}
		}
        $this->setRedirect(
        	JRoute::_('index.php?option=com_tablebooking&view=bookings', false),
        );
	}

}

?>
