<?php
/*
 * @component Tablebooking
 * @website : ionutlupu.me
 * @copyright  Ionut Lupu. All rights reserved.
 * @license : http://www.gnu.org/copyleft/gpl.html GNU/GPL , see license.txt
 */
 
 
// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

class TbBookingsList
{
	public $day;
	public $bookings;
	protected static $results;
	public $filter = array();


	protected function __construct( $day )
	{
		$this->day = $day;
		$this->getResults();
	}
	

	public static function getInstance($day)
	{
		if(!isset(self::$results[$day]))
		{
			self::$results[$day] = new TbBookingsList($day);
		}
		return self::$results[$day];
	}


	/**
	 *
	 * get all bookings for the day
	 * 
	 * @return object
	 */
	protected function getResults()
	{
		$db = JFactory::getDbo();
		$query = $db->getQuery( true );
		$query->select(
					$db->quoteName('id') . ',' . $db->quoteName('name') .','. $db->quoteName('email') . ',' . $db->quoteName('phone') . ',' . $db->quoteName('table') . ','
					. $db->quoteName('comments') . ',' . $db->quoteName('bookend') . ',' . $db->quoteName('status') . ',' . $db->quoteName('bookstart')
					);
		$query->from( $db->quoteName('#__tbb_bookings') );
		$query->where( $db->quoteName('bookdate') . ' = ' . $db->quote($this->day) ) ;
		
		$db->setQuery( $query );
		$this->bookings = $db->loadObjectList();
		return $this;
	}


	/**
	 * filter the current bookings for a certain table
	 */
	public function forTable( $id ) 
	{	
		$filter = array();

		foreach ($this->filter as $booking) 
		{
			if (preg_match('/"'.$id.'"/', $booking->table)) 
			{
				$filter[] = $booking;
			}
		}
		
		$this->filter = $filter;
		return $this;
	}
	
	
	/**
	 * filter the current bookings for a certain hour
	 */
	public function forHour( $hour )
	{	
		$filter = array();

		foreach ( $this->filter as $booking )
		{	
		    if ( $booking->bookstart == $hour || ( $booking->bookend > $hour && $booking->bookstart <= $hour ) )
		    {
			  	$filter[] = $booking;
		    }
		}
		
		$this->filter = $filter;
		return $this;
	}	


	/**
	 * clear the filter so we can filter again 
	 */
	public function clear() 
	{
		$this->filter = $this->bookings;
		return $this;
	}


}
