<?php
/*
 * @component Tablebooking
 * @website : ionutlupu.me
 * @copyright  Ionut Lupu. All rights reserved.
 * @license : http://www.gnu.org/copyleft/gpl.html GNU/GPL , see license.txt
 */
 
 
// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

class TbRestaurant{

    public $id;
    public $title;
    public $params;
    public $schedule;
    public $min_capacity = 0;
    public $max_capacity = 0;
    protected static $instance;
    

    public static function getInstance( $id )
    {
	    if (!isset(self::$instance[$id])) {
		    self::$instance[$id] = new TbRestaurant( $id );
	    }
	    return self::$instance[$id];
    }

    
    protected function __construct( $id )
    {
		if (!$id) 
		{
			throw new Exception('No restaurant with this id');
		}
	    $this->id = $id;
	    $this->bind($this->getDetails());
        $this->setLimits();
    }
    


    /**
     *
     * get restaurant details to bind them
     * 
     */
    protected function getDetails()
    {
    
	    $db = JFactory::getDbo();
	    $query = $db->getQuery(true);
	    $query->select( $db->quoteName('title') . ' , ' . $db->quoteName('params') . ',' .  $db->quoteName('schedule') . ',' . $db->quoteName('published') );
	    $query->from( $db->quoteName('#__tbb_restaurants') );
	    $query->where( $db->quoteName('id') . ' = ' . $this->id );
	
	    $db->setQuery( $query );
	    return $db->loadAssoc(); 
    }
    

    /**
     *
     * method to bind restaurant details when creating an instance
     * 
     * @param  [array] $details [restaurant details: title, params, publishd]
     * @return mixed 
     */
    protected function bind( $details )
    {
        if (!empty($details))
        {
            foreach ($details as $key=>$value)
            {
                $this->{$key} = $value; 
            }
        }
    }
    

  	/**
  	 *
  	 * get all restaurant tables
  	 * 
  	 * @param  [int] $min [optional, filter by minimum places]
  	 * @param  [int] $max [optional, filter by maximum places]
  	 * @return [array]
  	 */
    public function getTables($min = null, $max = null)
    {
	    $db = JFactory::getDbo();
	    $query = $db->getQuery(true);

	    $query->select( $db->quoteName('id') . ' , ' . $db->quoteName('name') . ' , ' . $db->quoteName('min_places') . ' , ' . $db->quoteName('max_places') . ' , ' . $db->quoteName('shape') . ' , ' . $db->quoteName('params'));
	    $query->from( $db->quoteName('#__tbb_tables') );
	    if ($min) 
	    {
	    	$query->where($db->quoteName('min_places') .' > ' . (int) $min);
	    }
	    if ($max)
	    {
	    	$query->where($db->quoteName('max_places') .' < ' . (int) $max);
	    }
	    $query->where( $db->quoteName('restaurant') . ' = ' . $this->id );
	    
	    $db->setQuery( $query );
	    return $db->loadObjectList();
    }
    
    
    /**
     * get all bookings for a certain day
     * 
     * @param  [mixed] $day [can be a timestamp or a date formatted string (YYYY-mm-dd)]
     * @return array
     */
    public function getBookings( $day )
    {
    	$zi = new TbDay($day);  
	    return new TbBookingsList( $zi );
    }
    

    /**
     *
     * return a schedule object
     * 
     * @return [object]    
     */
    public function getSchedule( $day )
    {
	    return new TbSchedule( $this, $day );
    }


    /**
     * 
     * get restaurant params 
     * params include restaurant settings regarding hours of operation, date and time format
     * 
     * @return array
     */
    public function getParams() 
    {

	   $params = !empty($this->params) ? json_decode( $this->params ) : array();
	
	   return TbParams::getInstance($params,$this->id);
    }


    // set minimum and maximum that someone can book
    protected function setLimits()
    {
        $booked = array();
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select('MIN(min_places) as min, MAX(max_places) AS max');
        $query->from($db->quoteName('#__tbb_tables'));
        $query->where('restaurant = ' . $this->id);

        $db->setQuery($query);
        $limits = $db->loadObject();

        $this->min_capacity = (int) $limits->min;
        $this->max_capacity = (int) $limits->max;
    }
}
