<?php
/*
 * @component Tablebooking
 * @website : ionutlupu.me
 * @copyright  Ionut Lupu. All rights reserved.
 * @license : http://www.gnu.org/copyleft/gpl.html GNU/GPL , see license.txt
 */
 
 
// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

jimport('joomla.utilities.date');

class TbSchedule{

	protected $restaurant;
	protected $timeframe = 900;
	protected $intervals = array();
	protected $date;
	public $working = true;
	public $isSet = false;


	public function __construct( TbRestaurant $restaurant, $day )
	{
		$this->restaurant = $restaurant;
		$this->_for( $day );
	}


    /**
     * specify the date/day of week
     */
    protected function _for( $input )
    {	
    	if ($input instanceof JDate)
    	{
    		$this->date = $input->format('Y-m-d');
    	}
    	else
    	{
    		$this->date = $input;
    	}

    	$encoded = isset($this->restaurant->schedule) ? unserialize($this->restaurant->schedule) : array();

		if(isset($encoded[$this->date]))
		{
			$this->isSet = true;
			$this->working = isset($encoded[$this->date]->working) ? $encoded[$this->date]->working : 1;
			$this->intervals = isset($encoded[$this->date]->intervals) ? $encoded[$this->date]->intervals : array();			
		} 
    }



	/**
	 * get all available hours for the day
	 * @return [array] 
	 */
	public function getHours( $translated = false )
	{	
		$hours = array();
		$params = $this->restaurant->getParams();

		if ($this->working)
		{
			foreach( $this->intervals as $key=>$interval )
			{
				for($i=$interval['start'];$i<=$interval['end'];$i+=$params->timeframe)
				{
					$hours[$i] = $translated ? TbDisplay::showTime($i, $params->hourformat) : $i;
				}
			}
		}

		return $hours ? $hours : $this->getDefaultHours($translated);
	}


	public function getIntervals()
	{
		return $this->intervals;
		
	}

	/**
	 *
	 * return default hours in case no schedule is set for that date/day of week
	 * start with opening hour for restaurant and end with closing hour of restaurant
	 * 
	 * @return [type] [description]
	 */
 	public function getDefaultHours($translated = true)
    {   
      
        $params = $this->restaurant->getParams();
        $hours = array();
   
        for ( $i = $params->starthour; $i <= $params->endhour ; $i+= $params->timeframe  )
        {
            $hours[$i] = $translated ? TbDisplay::showTime($i, $params->hourformat) : $i;
        }
        return $hours;
    }

 

	/**
	 * get a datetime object depending on the website offset
	 * @return [integer]
	 */
	public static function getDate( $timestamp )
	{
		$tz = new DateTimeZone(JFactory::getApplication()->getCfg('offset'));
		$now = JFactory::getDate($timestamp);
		$now->setTimeZone($tz);

		return $now;
	}

}
