<?php
/*
 * @component Tablebooking
 * @website : ionutlupu.me
 * @copyright  Ionut Lupu. All rights reserved.
 * @license : http://www.gnu.org/copyleft/gpl.html GNU/GPL , see license.txt
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.modellist');
jimport('joomla.utilities.date');

class TableBookingModelBookings extends JModelList
{

	public function __construct($config = array()) {
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array();
		}
		parent::__construct($config);
	}


	protected function populateState($ordering = null, $direction = null) {

		// Initialise variables.
		$app = JFactory::getApplication();
		$day = new TbDay('now');

		$datephp = $app->getUserStateFromRequest($this->context.'.filter.bookings.datephp', 'filter_bookings_datephp', '', 'string');
		$this->setState('filter.bookings.datephp', $datephp);

		$state = $app->getUserStateFromRequest($this->context.'.filter.bookings.status', 'filter_status', -1, '');
		$this->setState('filter.bookings.status', $state);

		$state = $app->getUserStateFromRequest($this->context.'.filter.bookings.timestamp', 'filter_bookings_timestamp', null, 'string');
		$this->setState('filter.bookings.timestamp', $state);

		$state = $app->getUserStateFromRequest($this->context.'.filter.bookings.search', 'filter_search', null, 'string');
		$this->setState('filter.bookings.search', $state);

		// List state information.
		parent::populateState('a.id', 'desc');
	}

	protected function getStoreId($id = '') {

		// Compile the store id.
		$id	.= ':'.$this->getState('filter.bookings.status');
		$id	.= ':'.$this->getState('filter.bookings.datephp');
		$id	.= ':'.$this->getState('filter.bookings.timestamp');
		$id	.= ':'.$this->getState('filter.bookings.search');

		return parent::getStoreId($id);
	}



	protected function getListQuery()
	{
		$booking_list_display = TbUser::getInstance()->work->restaurant->getParams()->booking_list_display;
		$query = $this->_db->getQuery(true);

		$query->select('id, name, bookstart, bookend, bookdate, status, places, comments, `table`, phone');
		$query->from($this->_db->quoteName('#__tbb_bookings'));

		$date = $this->getState('filter.bookings.datephp', null);
		if ($date)
		{
			$query->where('bookdate = ' . $this->_db->quote($this->_db->escape($date)));
		}
		else
		{
			if ($booking_list_display == 1)
			{
				$query->where('bookdate >= NOW()');
			}
		}

		$status = $this->getState('filter.bookings.status', -1);
		if ($status != -1)
		{
			$query->where('status = ' . (int) $status);
		}

		$search = $this->getState('filter.bookings.search', '');
		if ($search)
		{
			$rxsearch = $this->_db->quote($this->_db->escape('%' . $search . '%'));
			$search = $this->_db->quote($this->_db->escape($search));
			$query->where('name = ' . $search . ' OR name LIKE ' . $rxsearch);
		}

		$query->where( $this->_db->quoteName('restaurant') . ' = ' . TbUser::getInstance()->work->restaurant->id );

		if ($booking_list_display == 1)
		{
			$query->order('bookdate ASC');
		}
		return $query;
	}

	/**
	 *  get export object containing details like filetype, mime and name
	 */
	public function getExport()
	{
		$exported = new stdclass;
		$exported->mimetype = 'text/csv';
		$exported->filetype = 'csv';
		$exported->basename = JText::_('COM_TABLEBOOKING_BOOKINGS') . '_' . date('Y-m-d',time());

		return $exported;
	}


	/**
	 * retrieve content to put inside the exported file
	 * @return [string]
	 */
	public function getExportContent()
	{
		$content = $this->getCsv();
		return $content;
	}


	public function getCSV()
	{
		if (!isset($this->content)) {

			$this->content = '';
			$this->content.=
			'"'.str_replace('"', '""', JText::_('COM_TABLEBOOKING_BOOKINGS_CLIENT_NAME')).'","'.
				str_replace('"', '""', JText::_('COM_TABLEBOOKING_DATE')).'","'.
				str_replace('"', '""', JText::_('COM_TABLEBOOKING_BOOKINGS_START')).'","'.
				str_replace('"', '""', JText::_('COM_TABLEBOOKING_BOOKINGS_END')).'","'.
				str_replace('"', '""', JText::_('COM_TABLEBOOKING_PLACES')).'","'.
				str_replace('"', '""', JText::_('COM_TABLEBOOKING_CLIENT_COMMENTS')).'","'.
				str_replace('"', '""', JText::_('COM_TABLEBOOKING_BOOKINGS_STATUS')).'"' . "\n";

			foreach($this->getItems() as $item) {

				$restaurant = TbUser::getInstance()->work->restaurant;
				$statuses = array(JText::_('COM_TABLEBOOKING_UNCONFIRMED'), JText::_('COM_TABLEBOOKING_CONFIRMED'), JText::_('COM_TABLEBOOKING_CANCELED'), JText::_('COM_TABLEBOOKING_SEATED'));
				$date = TbDisplay::showDate($item->bookdate,$restaurant->getParams()->dateformat);
				$time = TbDisplay::showTime($item->bookstart,$restaurant->getParams()->hourformat);
				$finish = TbDisplay::showTime($item->bookend,$restaurant->getParams()->hourformat);

				$this->content.=
				'"'.str_replace('"', '""', $item->name).'","'.
					str_replace('"', '""', $date).'","'.
					str_replace('"', '""', $time).'","'.
					str_replace('"', '""', $finish).'","'.
					str_replace('"', '""', $item->places).'","'.
					str_replace('"', '""', $item->comments).'","'.
					str_replace('"', '""', $statuses[$item->status]).'"' . "\n";
			}
		}
		return $this->content;
	}

}
?>
